@@ -1,5 +1,7 @@
 from pyspark.sql import DataFrame
 from sparta.logs import getlogger
+from time import time
+from datetime import timedelta
 
 def save_df_azure_dw(df: DataFrame, url_jdbc: str, tempdir: str, table: str, mode:str ='overwrite', max_str_length:int =4000) -> None:
     """Function to write to an Azure SQL DW.
@@ -16,6 +18,9 @@ def save_df_azure_dw(df: DataFrame, url_jdbc: str, tempdir: str, table: str, mod
         ValueError: In case the mode values are not -> append or overwrite.
     """
     logger = getlogger('save_df_azure_dw')
+    
+    start_time = time()
+    
     if mode == 'append':
         df.write.format('com.databricks.spark.sqldw').option('url', url_jdbc)\
             .option('forwardSparkAzureStorageCredentials', 'true').option('dbTable', table)\
@@ -23,6 +28,7 @@ def save_df_azure_dw(df: DataFrame, url_jdbc: str, tempdir: str, table: str, mod
             .option("batchsize", "100000").option("numPartitions", 32).option("tempDir", tempdir)\
                 .mode(mode).save()
         logger.info(f'Writing of table {table} to the database is complete.')
+        logger.info(f"Execution time: {timedelta(seconds = time()-start_time)}")
     elif mode == 'overwrite':
         df.write.format('com.databricks.spark.sqldw').option('url', url_jdbc)\
             .option('forwardSparkAzureStorageCredentials', 'true').option('dbTable', table)\
@@ -30,6 +36,7 @@ def save_df_azure_dw(df: DataFrame, url_jdbc: str, tempdir: str, table: str, mod
             .option("batchsize", "100000").option("numPartitions", 32).option("truncate", True)\
                 .option("tempDir", tempdir).mode(mode).save()
         logger.info(f'Writing of table {table} to the database is complete.')
+        logger.info(f"Execution time: {timedelta(seconds = time()-start_time)}")
     else:
         raise ValueError(f"mode {mode} doesn't exist. Use overwrite or append.")
 
@@ -46,6 +53,10 @@ def create_hive_table(df: DataFrame, table: str, value: int,*keys:str) -> None:
     Example:
         >>> create_hive_table(df, "table_name", 5, "col1", "col2", "col3")
     """
-    df.write.format('parquet').bucketBy(value, keys).mode("overwrite").saveAsTable(table)
     logger = getlogger('create_hive_table')
-    logger.info(f'Table {table} was successfully created in Hive.')
\ No newline at end of file
+    
+    start_time = time()
+    
+    df.write.format('parquet').bucketBy(value, keys).mode("overwrite").saveAsTable(table)
+    logger.info(f'Table {table} was successfully created in Hive.')
+    logger.info(f"Execution time: {timedelta(seconds = time()-start_time)}")
\ No newline at end of file
